@@ -4,9 +4,9 @@
 # Use of this source code is governed by a BSD-style license that can be
 # found in the LICENSE file.
 
-"""
-Prints release announce based on HISTORY.rst file content.
-See: https://pip.pypa.io/en/stable/reference/pip_install/#hash-checking-mode
+"""Prints release announce based on HISTORY.rst file content.
+See: https://pip.pypa.io/en/stable/reference/pip_install/#hash-checking-mode.
+
 """
 
 import os
@@ -14,21 +14,24 @@ import re
 import subprocess
 import sys
 
-from psutil import __version__ as PRJ_VERSION
+from psutil import __version__
 
 
 HERE = os.path.abspath(os.path.dirname(__file__))
 ROOT = os.path.realpath(os.path.join(HERE, '..', '..'))
 HISTORY = os.path.join(ROOT, 'HISTORY.rst')
 PRINT_HASHES_SCRIPT = os.path.join(
-    ROOT, 'scripts', 'internal', 'print_hashes.py')
+    ROOT, 'scripts', 'internal', 'print_hashes.py'
+)
 
 PRJ_NAME = 'psutil'
+PRJ_VERSION = __version__
 PRJ_URL_HOME = 'https://github.com/giampaolo/psutil'
 PRJ_URL_DOC = 'http://psutil.readthedocs.io'
 PRJ_URL_DOWNLOAD = 'https://pypi.org/project/psutil/#files'
-PRJ_URL_WHATSNEW = \
+PRJ_URL_WHATSNEW = (
     'https://github.com/giampaolo/psutil/blob/master/HISTORY.rst'
+)
 
 template = """\
 Hello all,
@@ -47,7 +50,7 @@ line tools such as: ps, top, lsof, netstat, ifconfig, who, df, kill, free, \
 nice, ionice, iostat, iotop, uptime, pidof, tty, taskset, pmap. It \
 currently supports Linux, Windows, macOS, Sun Solaris, FreeBSD, OpenBSD, \
 NetBSD and AIX, both 32-bit and 64-bit architectures.  Supported Python \
-versions are 2.7 and 3.4+. PyPy is also known to work.
+versions are 2.7 and 3.6+. PyPy is also known to work.
 
 What's new
 ==========
@@ -83,13 +86,15 @@ def get_changes():
     block = []
 
     # eliminate the part preceding the first block
-    for line in lines:
+    while lines:
         line = lines.pop(0)
         if line.startswith('===='):
             break
-    lines.pop(0)
+    else:
+        raise ValueError("something wrong")
 
-    for line in lines:
+    lines.pop(0)
+    while lines:
         line = lines.pop(0)
         line = line.rstrip()
         if re.match(r"^- \d+_", line):
@@ -98,6 +103,8 @@ def get_changes():
         if line.startswith('===='):
             break
         block.append(line)
+    else:
+        raise ValueError("something wrong")
 
     # eliminate bottom empty lines
     block.pop(-1)
@@ -109,9 +116,12 @@ def get_changes():
 
 def main():
     changes = get_changes()
-    hashes = subprocess.check_output(
-        [sys.executable, PRINT_HASHES_SCRIPT, 'dist/']).strip().decode()
-    print(template.format(
+    hashes = (
+        subprocess.check_output([sys.executable, PRINT_HASHES_SCRIPT, 'dist/'])
+        .strip()
+        .decode()
+    )
+    text = template.format(
         prj_name=PRJ_NAME,
         prj_version=PRJ_VERSION,
         prj_urlhome=PRJ_URL_HOME,
@@ -120,7 +130,8 @@ def main():
         prj_urlwhatsnew=PRJ_URL_WHATSNEW,
         changes=changes,
         hashes=hashes,
-    ))
+    )
+    print(text)
 
 
 if __name__ == '__main__':
